@@ -1,7 +1,7 @@
 #
 # tmail.rb
 #
-#   Copyright (c) 1998-1999 Minero Aoki <aamine@dp.u-netsurf.ne.jp>
+#   Copyright (c) 1998-2000 Minero Aoki <aamine@dp.u-netsurf.ne.jp>
 #
 #   This program is free software.
 #   You can distribute/modify this program under the terms of
@@ -25,16 +25,17 @@ class MailError < StandardError ; end
 
 module TMail
 
-  Version = '0.8.1'
+  Version = '0.8.3'
 
 
 class Mail
 
   class << self
 
-    def loadfrom( fname )
+    def load_from( fname )
       new FilePort.new( fname )
     end
+    alias loadfrom load_from
 
 
     def boundary
@@ -127,20 +128,20 @@ class Mail
 
 
   def encoded( eol = "\r\n", charset = 'j', ret = '', sep = '' )
-    visitor = HFencoder.new( ret, eol, charset )
-    accept visitor, eol, ret, sep
+    stra = HFencoder.new( ret, eol, charset )
+    accept stra, eol, ret, sep
     ret
   end
   alias to_s encoded
 
   def decoded( eol = "\n", charset = 'e', ret = '', sep = '' )
-    visitor = HFdecoder.new( ret, charset )
-    accept visitor, eol, ret, sep
+    stra = HFdecoder.new( ret, charset )
+    accept stra, eol, ret, sep
     ret
   end
   alias inspect decoded
 
-  def accept( visitor, eol = "\n", ret = '', sep = '' )
+  def accept( stra, eol = "\n", ret = '', sep = '' )
     multipart = ! @parts.empty?
 
     if multipart then
@@ -154,8 +155,8 @@ class Mail
     end
 
     each_header do |name, header|
-      header.accept visitor
-      visitor.write_in
+      header.accept stra
+      stra.write_in
       ret << eol
     end
     ret << sep << eol
@@ -171,7 +172,7 @@ class Mail
       boundary = "#{eol}--#{bound}#{eol}"
       parts.each do |tm|
         ret << boundary
-        tm.accept( visitor, eol, ret, sep )
+        tm.accept( stra, eol, ret, sep )
       end
       ret << "#{eol}--#{bound}--#{eol}"
       s = epilogue
